Give data on x, y, z coordinate values of a 3D surface, this function plots them after making pillars near each z value by adding and subtracting small amounts dz. Instead of pins of the height z this creates pillars which better resemble a surface. It uses the wireframe() function of `lattice' package to do the plotting.
pillar3D(
z = c(657, 936, 1111, 1201),
x = c(280, 542, 722, 1168),
y = c(162, 214, 186, 246),
drape = TRUE,
xlab = "y",
ylab = "x",
zlab = "z",
mymain = "Pillar Chart"
)A 3D plot
z-coordinate values
x-coordinate values
y-coordinate values
logical value, default drape=TRUE to give color to heights
default "x" label on the x axis
default "y" label on the y axis
default "z" label on the z axis
default "Pillar Chart" main label on the plot
Prof. H. D. Vinod, Economics Dept., Fordham University, NY
For additional plotting features type `pillar3D()' on the R console to get my code and adjust wireframe() function defaults.